changeset 17768:93caf447ed72

Make functions setup-LANGUAGE-environment interactive and add new functions describe-LANGUAGE-support for all LANGUAGEs supported. Remove resisterations of input methods which use the function encoded-kbd-select-terminal. Typo in comment fixed.
author Kenichi Handa <handa@m17n.org>
date Mon, 12 May 1997 07:00:09 +0000
parents d93b9414ff2b
children 37ae0c18bd47
files lisp/language/european.el
diffstat 1 files changed, 18 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/language/european.el	Mon May 12 07:00:08 1997 +0000
+++ b/lisp/language/european.el	Mon May 12 07:00:09 1997 +0000
@@ -69,23 +69,36 @@
 		       '("quail-latin-5" quail-use-package "quail/latin"))
 
 (defun setup-european-environment ()
+  "Setup multilingual environment (MULE) for European languages users.
+It actually reset MULE to the default status, and
+set quail-latin-1 as the default input method to be selected.
+See also the documentation of setup-english-environment."
   (setup-english-environment)
+  (setq default-input-method '("European" . "quail-latin-1")))
 
-  (setq default-input-method '("European" . "quail-latin-1"))
-  )
+(defun describe-european-support ()
+  "Describe how Emacs support European languages."
+  (interactive)
+  (describe-language-support-internal "European"))
 
 (set-language-info-alist
  "European" '((setup-function . setup-european-environment)
+	      (describe-function . describe-european-support)
 	      (charset . (ascii latin-iso8859-1 latin-iso8859-2
 			  latin-iso8859-3 latin-iso8859-4 latin-iso8859-9))
 	      (coding-system . (iso-8859-1 iso-8859-2 iso-8859-3
 				iso-8859-4 iso-8859-9))
-	      (documentation . t)
 	      (sample-text
-	       . "Hello, Hej, Tere, Hei, Bonjour, Gr,A|_(B Gott, Ciao, ,A!(BHola!")))
+	       . "Hello, Hej, Tere, Hei, Bonjour, Gr,A|_(B Gott, Ciao, ,A!(BHola!")
+	      (documentation . "\
+Almost all of European languages are supported by the character sets and
+coding systems listed below.
+To input them, LEIM (Libraries for Emacs Input Methods) should have been
+installed.")
+	      ))
 
 (let ((languages '("French" "German" "Spanish" "Italian"
 		   ;; We have to list much more European langauges here.
 		   ))
       (val '("quail-latin-1" quail-use-package "quail/latin")))
   (while languages
@@ -69,23 +69,36 @@
 
 (let ((languages '("French" "German" "Spanish" "Italian"
-		   ;; We have to list much more European langauges here.
+		   ;; We have to list much more European languages here.
 		   ))
       (val '("quail-latin-1" quail-use-package "quail/latin")))